@@ -41,14 +41,12 @@
 
 var cvPrefs = 0;
 var addressbook = 0;
-var gAddressBookBundle;
 var gSearchTimer = null;
 var gStatusText = null;
 var gQueryURIFormat = null;
 var gSearchInput;
 var gPrintSettings = null;
 var gDirTree;
-var gSearchBox;
 var gCardViewBox;
 var gCardViewBoxEmail1;
 var gPreviousDirTreeIndex = -1;
@@ -175,7 +173,6 @@ function OnLoadAddressBook()
 
 function delayedOnLoadAddressBook()
 {
-  gAddressBookBundle = document.getElementById("bundle_addressBook");
   gSearchInput = document.getElementById("searchInput");
 
   verifyAccounts(null); 	// this will do migration, if we need to.
@@ -423,36 +420,6 @@ function AbOnRenameAddressBook(aName)
   addressbook.modifyAddressBook(addressbookDS, parentDir, selectedABDirectory, properties);
 }
 
-function GetPrintSettings()
-{
-  var prevPS = gPrintSettings;
-
-  try {
-    if (gPrintSettings == null) {
-      var useGlobalPrintSettings = true;
-      var pref = Components.classes["@mozilla.org/preferences-service;1"]
-                           .getService(Components.interfaces.nsIPrefBranch);
-      if (pref) {
-        useGlobalPrintSettings = pref.getBoolPref("print.use_global_printsettings", false);
-      }
-
-      // I would rather be using nsIWebBrowserPrint API
-      // but I really don't have a document at this point
-      var printSettingsService = Components.classes["@mozilla.org/gfx/printsettings-service;1"]
-                                           .getService(Components.interfaces.nsIPrintSettingsService);
-      if (useGlobalPrintSettings) {
-        gPrintSettings = printSettingsService.globalPrintSettings;
-      } else {
-        gPrintSettings = printSettingsService.CreatePrintSettings();
-      }
-    }
-  } catch (e) {
-    dump("GetPrintSettings "+e);
-  }
-
-  return gPrintSettings;
-}
-
 function AbPrintCardInternal(doPrintPreview, msgType)
 {
   var selectedItems = GetSelectedAbCards();
@@ -486,7 +453,7 @@ function AbPrintCardInternal(doPrintPreview, msgType)
 
   if (!gPrintSettings)
   {
-    gPrintSettings = GetPrintSettings();
+    gPrintSettings = PrintUtils.getPrintSettings();
   }
 
   printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xul",
@@ -534,7 +501,7 @@ function AbPrintAddressBookInternal(doPrintPreview, msgType)
   var printUrl = "addbook://" + abURIArr[0] + "/" + abURIArr[1] + "?action=print"
 
   if (!gPrintSettings) {
-    gPrintSettings = GetPrintSettings();
+    gPrintSettings = PrintUtils.getPrintSettings();
   }
 
 	printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xul",
@@ -615,7 +582,6 @@ function AbDeleteDirectory()
     // Check if this address book is being used for collection
     if (gPrefs.getCharPref("mail.collect_addressbook") == selectedABURI &&
         (gPrefs.getBoolPref("mail.collect_email_address_outgoing") ||
-         gPrefs.getBoolPref("mail.collect_email_address_incoming") ||
          gPrefs.getBoolPref("mail.collect_email_address_newsgroup"))) {
       var brandShortName = document.getElementById("bundle_brand").getString("brandShortName");
 
@@ -638,7 +604,6 @@ function AbDeleteDirectory()
   // First clear all the prefs if required
   if (clearPrefsRequired) {
     gPrefs.setBoolPref("mail.collect_email_address_outgoing", false);
-    gPrefs.setBoolPref("mail.collect_email_address_incoming", false);
     gPrefs.setBoolPref("mail.collect_email_address_newsgroup", false);
 
     // Also reset the displayed value so that we don't get a blank item in the
@@ -661,7 +626,7 @@ function SetStatusText(total)
   try {
     var statusText;
 
-    if (gSearchInput.value) {
+    if (gSearchInput && gSearchInput.value) {
       if (total == 0)
         statusText = gAddressBookBundle.getString("noMatchFound");
       else
@@ -747,13 +712,13 @@ function SwitchPaneFocus(event)
   var focusedElement    = WhichPaneHasFocus();
   var cardViewBox       = GetCardViewBox();
   var cardViewBoxEmail1 = GetCardViewBoxEmail1();
-  var searchBox         = GetSearchBox();
+  var searchBox         = document.getElementById('search-container');
   var dirTree           = GetDirTree();
   var searchInput       = GetSearchInput();
 
   if (event && event.shiftKey)
   {
-    if (focusedElement == gAbResultsTree && searchBox.getAttribute('hidden') != 'true')
+    if (focusedElement == gAbResultsTree && searchBox)
       searchInput.focus();
     else if ((focusedElement == gAbResultsTree || focusedElement == searchBox) && !IsDirPaneCollapsed())
       dirTree.focus();
@@ -780,7 +745,7 @@ function SwitchPaneFocus(event)
     }
     else if (focusedElement != dirTree && !IsDirPaneCollapsed())
       dirTree.focus();
-    else if (searchBox.getAttribute('hidden') != 'true')
+    else if (searchBox)
       searchInput.focus();
     else
       gAbResultsTree.focus();
@@ -790,7 +755,7 @@ function SwitchPaneFocus(event)
 function WhichPaneHasFocus()
 {
   var cardViewBox       = GetCardViewBox();
-  var searchBox         = GetSearchBox();
+  var searchBox         = document.getElementById('search-container');
   var dirTree           = GetDirTree();
     
   var currentNode = top.document.commandDispatcher.focusedElement;
@@ -824,13 +789,6 @@ function GetSearchInput()
   return gSearchInput;
 }
 
-function GetSearchBox()
-{
-  if (!gSearchBox)
-    gSearchBox = document.getElementById('searchBox');
-  return gSearchBox;
-}
-
 function GetCardViewBox()
 {
   if (!gCardViewBox)
